********
Datasets
********


Utils
-----

.. automodule:: toponetx.datasets.utils
   :members:

Graph
-----

.. automodule:: toponetx.datasets.graph
   :members:

Mesh
----

.. automodule:: toponetx.datasets.mesh
   :members: